@@ -2,7 +2,7 @@ use crate::render::portable::utils::{render_index_file, render_static_files};
 use crate::render::portable::ItemRenderer;
 use crate::render::Renderer;
 use crate::spec::ItemsSpec;
-use anyhow::{Context, Result};
+use anyhow::Result;
 use log::LevelFilter;
 use simplelog::{Config, SimpleLogger};
 use structopt::StructOpt;
@@ -15,10 +15,7 @@ pub(crate) mod utils;
 fn main() -> Result<()> {
     let opt = cli::Datavzrd::from_args();
     let _ = SimpleLogger::init(LevelFilter::Warn, Config::default());
-    let config = ItemsSpec::from_file(&opt.config).context(format!(
-        "Could not find config file under given path {:?}",
-        &opt.config
-    ))?;
+    let config = ItemsSpec::from_file(&opt.config)?;
     config.validate()?;
 
     if !opt.output.exists() {
